@@ -18,6 +18,7 @@ import argparse
 import itertools
 import logging
 import sys
+import typing as ty
 
 from openstack import exceptions as sdk_exceptions
 from osc_lib.command import command
@@ -132,7 +133,7 @@ def get_compute_quotas(
     default=False,
 ):
     try:
-        client = app.client_manager.sdk_connection.compute
+        client = app.client_manager.compute
         if default:
             quota = client.get_quota_set_defaults(project_id)
         else:
@@ -176,25 +177,37 @@ def get_network_quotas(
     default=False,
 ):
     def _network_quota_to_dict(network_quota, detail=False):
-        if not isinstance(network_quota, dict):
-            dict_quota = network_quota.to_dict()
-        else:
-            dict_quota = network_quota
+        dict_quota = network_quota.to_dict(computed=False)
 
-        result = {}
+        if not detail:
+            return dict_quota
 
+        # Neutron returns quota details in dict which is in format like:
+        # {'resource_name': {'in_use': X, 'limit': Y, 'reserved': Z},
+        #  'resource_name_2': {'in_use': X2, 'limit': Y2, 'reserved': Z2}}
+        #
+        # but Nova and Cinder returns quota in different format, like:
+        # {'resource_name': X,
+        #  'resource_name_2': X2,
+        #  'usage': {
+        #     'resource_name': Y,
+        #     'resource_name_2': Y2
+        #  },
+        #  'reserved': {
+        #     'resource_name': Z,
+        #     'resource_name_2': Z2
+        #  }}
+        #
+        # so we need to make conversion to have data in same format from
+        # all of the services
+        result: dict[str, ty.Any] = {"usage": {}, "reservation": {}}
         for key, values in dict_quota.items():
             if values is None:
                 continue
-
-            # NOTE(slaweq): Neutron returns values with key "used" but Nova for
-            # example returns same data with key "in_use" instead. Because of
-            # that we need to convert Neutron key to the same as is returned
-            # from Nova to make result more consistent
-            if isinstance(values, dict) and 'used' in values:
-                values['in_use'] = values.pop("used")
-
-            result[key] = values
+            if isinstance(values, dict):
+                result[key] = values['limit']
+                result["reservation"][key] = values['reserved']
+                result["usage"][key] = values['used']
 
         return result
 
@@ -243,7 +256,7 @@ class ListQuota(command.Lister):
         return parser
 
     def _list_quota_compute(self, parsed_args, project_ids):
-        compute_client = self.app.client_manager.sdk_connection.compute
+        compute_client = self.app.client_manager.compute
         result = []
 
         for project_id in project_ids:
@@ -278,7 +291,7 @@ class ListQuota(command.Lister):
             if default_result != project_result:
                 result += project_result
 
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'cores',
             'injected_files',
@@ -291,7 +304,7 @@ class ListQuota(command.Lister):
             'server_groups',
             'server_group_members',
         )
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'Project ID',
             'Cores',
             'Injected Files',
@@ -340,7 +353,7 @@ class ListQuota(command.Lister):
             if default_result != project_result:
                 result += project_result
 
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'backups',
             'backup_gigabytes',
@@ -349,7 +362,7 @@ class ListQuota(command.Lister):
             'snapshots',
             'volumes',
         )
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'Project ID',
             'Backups',
             'Backup Gigabytes',
@@ -395,7 +408,7 @@ class ListQuota(command.Lister):
             if default_result != project_result:
                 result += project_result
 
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'floating_ips',
             'networks',
@@ -407,7 +420,7 @@ class ListQuota(command.Lister):
             'subnets',
             'subnet_pools',
         )
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'Project ID',
             'Floating IPs',
             'Networks',
@@ -575,7 +588,7 @@ class SetQuota(common.NetDetectionMixin, command.Command):
         network_kwargs = {}
 
         if self.app.client_manager.is_compute_endpoint_enabled():
-            compute_client = self.app.client_manager.sdk_connection.compute
+            compute_client = self.app.client_manager.compute
 
             for k, v in COMPUTE_QUOTAS.items():
                 value = getattr(parsed_args, k, None)
@@ -767,6 +780,19 @@ and ``server-group-members`` output for a given quota class."""
             )
 
         info = {}
+        if parsed_args.usage:
+            info["reservation"] = compute_quota_info.pop("reservation", {})
+            info["reservation"].update(
+                volume_quota_info.pop("reservation", {})
+            )
+            info["reservation"].update(
+                network_quota_info.pop("reservation", {})
+            )
+
+            info["usage"] = compute_quota_info.pop("usage", {})
+            info["usage"].update(volume_quota_info.pop("usage", {}))
+            info["usage"].update(network_quota_info.pop("usage", {}))
+
         info.update(compute_quota_info)
         info.update(volume_quota_info)
         info.update(network_quota_info)
@@ -809,11 +835,11 @@ and ``server-group-members`` output for a given quota class."""
                 if k not in ('usage', 'reservation')
             ]
 
-        columns = (
+        columns: tuple[str, ...] = (
             'resource',
             'limit',
         )
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'Resource',
             'Limit',
         )
@@ -895,7 +921,7 @@ class DeleteQuota(command.Command):
             parsed_args.service == 'all'
             and self.app.client_manager.is_compute_endpoint_enabled()
         ):
-            compute_client = self.app.client_manager.sdk_connection.compute
+            compute_client = self.app.client_manager.compute
             compute_client.revert_quota_set(project.id)
 
         # volume quotas
